References
==========

.. _ref_anderson:

  1. Anderson, David F., 
     `A modified next reaction method for simulating chemical systems with time dependent propensities and delays <http://www.math.wisc.edu/~anderson/papers/AndNRM.pdf>`_,
     The Journal of Chemical Physics, Volume 127, Issue 21

.. _ref_arnaout:

  2. Arnaout, Ramy A., et al,
     `A simple relationship between viral load and survival time in HIV-1 infection <http://www.ncbi.nlm.nih.gov/pmc/articles/PMC18071/>`_,
     Proc Natl Acad Sci U S A. 1999 Sep 28; 96(20): 11549-11553.

.. _ref_hargrove:

  3. Hargrove, John, et al,
     `How Should We Best Estimate the Mean Recency Duration for the BED Method? <http://journals.plos.org/plosone/article?id=10.1371/journal.pone.0049661>`_,
     PLoS One 7(11): e49661.

.. _ref_fraser:

  4. Fraser, C., et al,
     `Variation in HIV-1 set-point viral load: Epidemiological analysis and an evolutionary hypothesis <http://www.ncbi.nlm.nih.gov/pubmed/17954909>`_,
     Proceedings of the National Academy of Sciences of the United States of America. 2007;104(44):17441-17446.

